#!/bin/sh
PEA="Notebook PEA 0.2"
JAR="notebook.jar"

# Unix script to start a PEA
# most parts of script are from http://www.gimlisys.com/articles-detect-java.html
# This script attempts to find an existing installation of Java that meets a minimum version
# requirement on a Linux machine.  If it is successful, it will export a JAVA_HOME environment
# variable that can be used by another calling script.
#
# To specify the required version, set the REQUIRED_VERSION to the major version required, 
# e.g. 1.3, but not 1.3.1.
REQUIRED_VERSION=1.6


# Transform the required version string into a number that can be used in comparisons
REQUIRED_VERSION=`echo $REQUIRED_VERSION | sed -e 's;\.;0;g'`

# 1. Check JAVA_HOME directory to see if Java version is adequate
if [ $JAVA_HOME ]
then
	JAVA_EXE=$JAVA_HOME/bin/java
	$JAVA_EXE -version 2> tmp.ver
	VERSION=`cat tmp.ver | grep "java version" | awk '{ print substr($3, 2, length($3)-2); }'`
	rm tmp.ver
	VERSION=`echo $VERSION | awk '{ print substr($1, 1, 3); }' | sed -e 's;\.;0;g'`
	if [ $VERSION ]
	then
		if [ $VERSION -ge $REQUIRED_VERSION ]
		then
			JAVA_HOME=`echo $JAVA_EXE | awk '{ print substr($1, 1, length($1)-9); }'`
		else
			JAVA_HOME=
			echo 'Your current default version of java is too old. Try to find more recent version...'
		fi
	else
		JAVA_HOME=
	fi
else
	echo 'JAVA_HOME not set'
fi

# 2. If the existing JAVA_HOME directory is adequate, then leave it alone
# otherwise, use 'locate' to search for other possible java candidates and
# check their versions.
if [ $JAVA_HOME ]
then
	:
else
#	for JAVA_EXE in `locate bin/java | grep java$ | xargs echo`
# replace locate by find
	for JAVA_EXE in `find bin/java | grep java$ | xargs echo`
	do
		if [ $JAVA_HOME ] 
		then
			:
		else
			$JAVA_EXE -version 2> tmp.ver 1> /dev/null
			VERSION=`cat tmp.ver | grep "java version" | awk '{ print substr($3, 2, length($3)-2); }'`
			rm tmp.ver
			VERSION=`echo $VERSION | awk '{ print substr($1, 1, 3); }' | sed -e 's;\.;0;g'`
			if [ $VERSION ]
			then
				if [ $VERSION -ge $REQUIRED_VERSION ]
				then
					JAVA_HOME=`echo $JAVA_EXE | awk '{ print substr($1, 1, length($1)-9); }'`
				fi
			fi
		fi
	done
fi



# If the correct Java version is detected, then export the JAVA_HOME environment variable
if [ $JAVA_HOME ]
then
	export JAVA_HOME
	#echo $JAVA_HOME
	#echo cat | $JAVA_HOME/bin/java -version
	echo 'Start' $PEA
	$JAVA_HOME/bin/java -jar $JAR
else 
	##########################################
	# 3. check other locations manually: 
	# This works for example for Linux Mint
	#
	# Try to find an executable java file in typical locations...
	if [ -x /usr/bin/java ];
	then		
		_JAVA=/usr/bin/java
	else
		# FreeBSD...
		if [ -x /usr/local/openjdk8/bin/java ];
		then
			_JAVA=/usr/local/openjdk8/bin/java
		else
			if [ -x /usr/local/openjdk7/bin/java ];
			then
				_JAVA=/usr/local/openjdk7/bin/java
			else
				if [ -x /usr/local/openjdk6/bin/java ];
				then
					_JAVA=/usr/local/openjdk6/bin/java
				else
					# at least try which and hope the best
					_JAVA=$(which java)
				fi			
			fi			
		fi
	fi
	# check version if java was found
	if [ -n "$_JAVA" ];
	then
   		/usr/bin/java -version 2> tmp.ver
		VERSION=`cat tmp.ver | grep "java version" | awk '{ print substr($3, 2, length($3)-2); }'`
		rm tmp.ver
		VERSION=`echo $VERSION | awk '{ print substr($1, 1, 3); }' | sed -e 's;\.;0;g'`
		if [ $VERSION ]
		then
			#echo 'version: ' $VERSION
			if [ $VERSION -ge $REQUIRED_VERSION ]
			then	
				echo 'starting JRE by ' $_JAVA
				echo 'Start' $PEA
				$_JAVA -jar $JAR
			else
				echo 'The Java version found is too old. You need at least java 1.6 to run' $PEA
			fi
		else
			echo 'Cant find suitable java version. Sorry, you must install at least java 1.6 to run' $PEA
		fi
	else
		echo 'Cant find suitable java version. Sorry, you must install at least java 1.6 to run' $PEA
	fi
fi
echo "Press enter to close the terminal"
read tmp
